<?php

// Action hook to load widget
add_action( 'widgets_init', 'wd_searchform' );

// register widget in WordPress so that it is available under the widgets section
function wd_searchform() {
	register_widget( 'wd_searchform' );
}

// Note: the name of the class and the name of the function should be the same
class wd_searchform extends WP_Widget {

	// Constructor
	function wd_searchform() {
		$widget_ops = array( 'classname' => 'wd-searchform', 'description' => __('A simple search form widget', 'wd-searchform') );
		
		$control_ops = array( 'id_base' => 'wd-searchform-widget' );
		
		$this->WP_Widget( 'wd-searchform-widget', __('WDsearchForm', 'wd-searchform'), $widget_ops, $control_ops );
	}
	
	// The widget itself
	function widget( $args, $instance ) {
		extract( $args );

		//Our variables from the widget settings.
		$title = apply_filters('widget_title', $instance['title'] );
		$dString = $instance['string'];
		$showWrapper = $instance['show_wrapper'];
		$animate = $instance['animate'];
		$animateWidth = $instance['animateWidth'];
		
		// Display the widget wrapper and title 
		if ( $showWrapper )
			echo $before_widget . $before_title . $title . $after_title;
		?>
		<script>
		var searchField = "form.wd_search input[name=s]";
		var submitBtn = "form.wd_search input[type=submit]";
		var animate = <?php echo ($animate == 'on' ? 'true' : 'false'); ?>;
		var focusWidth = <?php echo $animateWidth; ?>; // This much would be added on focus
		
		(function ($) { // wordpress uses 'jquery' instead of '$'
			$(document).ready(function() {
				
				$(searchField).focus(function() {
										
					// Change class and animate
					$(this).removeClass("idleField")
						   .addClass("focusField");
					
					if(animate)
						$(this).animate({width : "+=" + focusWidth});
					
					if (this.value == this.defaultValue){  
						this.value = ''; 
						
						// Enable submit
						$(submitBtn)
							.removeAttr("disabled")
							.addClass("hover"); // Change to hover style
					}  
					if(this.value != this.defaultValue){  
						this.select();  
					}
				})
				.blur(function() {  
       				
       				// Change class and animate
       				$(this).removeClass("focusField")
       					   .addClass("idleField");
        				   
        			if(animate)
						$(this).animate({width : "-=" + focusWidth});
        			
        			if ($.trim(this.value) == '') {  
            			this.value = this.defaultValue;
            			
            			// Disable submit
            			$(submitBtn)
            				.attr("disabled", "disabled")
            				.removeClass("hover"); // Change to default style
        			}
    			});
			});
		}(jQuery)); // Used to replace the global variable 'jquery' with '$' 
		</script>
		<form method="get" class="wd_search" action="<?php echo site_url(); ?>">
			<input type="text" name="s" class="idleField" value="<?php echo $dString ?>">
			<input type="submit" value="" name="searchsubmit" disabled="disabled" >
		</form>
		
		<?php // Display the last part of the wrapper
		echo ($showWrapper ? $after_widget : '');
	}

	//Update the widget 
	 
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		//Strip tags to remove HTML 
		$instance['string'] = strip_tags( $new_instance['string'] );
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['show_wrapper'] = strip_tags( $new_instance['show_wrapper'] );
		$instance['animate'] = strip_tags( $new_instance['animate'] );
		$instance['animateWidth'] = strip_tags( $new_instance['animateWidth'] );

		return $instance;
	}

	// The user's update form
	function form( $instance ) {

		//Set up some default widget settings.
		$defaults = array( 'title' => __('WDsearchForm', 'wd-searchform'), 'string' => __('Search', 'wd-searchform'), 'show_wrapper' => true, 'animate' => true, 'animateWidth' => 80 );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<?php /* Widget Title: Text Input.*/ ?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'wd-searchform'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		
		<?php /* Default String */ ?>
		<p>
			<label for="<?php echo $this->get_field_id( 'string' ); ?>"><?php _e('Default string:', 'wd-searchform'); ?></label>
			<input id="<?php echo $this->get_field_id( 'string' ); ?>" name="<?php echo $this->get_field_name( 'string' ); ?>" type="text" value="<?php echo $instance['string']; ?>" class="widefat" />
		</p>
		
		<?php /* Show_wrapper checkbox */ ?>
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['show_wrapper'], 'on' ); ?> id="<?php echo $this->get_field_id( 'show_wrapper' ); ?>" name="<?php echo $this->get_field_name( 'show_wrapper' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_wrapper' ); ?>"><?php _e('Display widget wrapper', 'wd-searchform'); ?></label>
		</p>
		
		<?php /* Animate checkbox */ ?>
		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['animate'], 'on' ); ?> id="<?php echo $this->get_field_id( 'animate' ); ?>" name="<?php echo $this->get_field_name( 'animate' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'animate' ); ?>"><?php _e('Animate', 'wd-searchform'); ?></label>
		</p>
		
		<?php /* Animate width */ ?>
		<p>
			<label for="<?php echo $this->get_field_id( 'animateWidth' ); ?>"><?php _e('Enlarge the width by (pixels):', 'wd-searchform'); ?></label>
			<input id="<?php echo $this->get_field_id( 'animateWidth' ); ?>" name="<?php echo $this->get_field_name( 'animateWidth' ); ?>" type="text" value="<?php echo $instance['animateWidth']; ?>" class="widefat" />
		</p>
		
	<?php
	}
}

?>